@@ -188,7 +188,7 @@
     </message>
     <message>
         <source>Maximum resolution:</source>
-        <translation type="unfinished"/>
+        <translation>ཞིབ་ཕྱིར་གྱི་གྲངས་ཆེན་པོ</translation>
     </message>
 </context>
 <context>
@@ -341,4 +341,4 @@
         <translation type="vanished">ཕབ་ལེན་བྱེད་མཚམས་འཇོག་པ།</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
