@@ -188,7 +188,7 @@
     </message>
     <message>
         <source>Maximum resolution:</source>
-        <translation type="unfinished"/>
+        <translation>Maximální rozlišení:</translation>
     </message>
 </context>
 <context>
@@ -341,4 +341,4 @@
         <translation type="vanished">Zastavit zaznamenávání</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
