@@ -188,7 +188,7 @@
     </message>
     <message>
         <source>Maximum resolution:</source>
-        <translation type="unfinished"/>
+        <translation>Resolusi maksimum:</translation>
     </message>
 </context>
 <context>
@@ -341,4 +341,4 @@
         <translation type="vanished">Henti rakaman</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
